@@ -4,9 +4,10 @@ from typing import Optional
 from .transformer import TransformerEncoder, FeedforwardBlock
 from .cnn import SpaceToDepth, calculate_output_spatial_size, spatial_tuple
 from .activation import ReLU, SquaredReLU, GELU, SwiGLU
-from .linear import SpectralNormLinear
+
 from einops import einsum
 from einops.layers.torch import Rearrange
+
 import torch.nn as nn
 import torch.nn.functional as F
 
@@ -57,14 +58,17 @@ class ClassificationHead(nn.Module):
         self,
         d_model,
         n_classes,
-        linear_module=nn.Linear,
         logit_projection_layer=nn.Linear,
         batch_norm_logits=True,
     ):
         super().__init__()
         self.d_model = d_model
         self.summarize = GetCLSToken()
-        self.projection = logit_projection_layer(d_model, n_classes)
+
+        if logit_projection_layer is not None:
+            self.projection = logit_projection_layer(d_model, n_classes)
+        else:
+            self.projection = nn.Identity()
 
         if batch_norm_logits:
             self.batch_norm = nn.BatchNorm1d(n_classes, affine=False)
@@ -90,9 +94,21 @@ class SequencePoolClassificationHead(ClassificationHead):
         as a generalisation of average pooling.
     """
 
-    def __init__(self, d_model, linear_module, out_dim, batch_norm=True):
-        super().__init__(d_model, linear_module, out_dim, batch_norm_logits=batch_norm)
-        self.summarize = SequencePool(d_model, linear_module)
+    def __init__(
+        self,
+        d_model,
+        n_classes,
+        logit_projection_layer=nn.Linear,
+        batch_norm_logits=True,
+    ):
+        super().__init__(
+            d_model,
+            n_classes,
+            logit_projection_layer=logit_projection_layer,
+            batch_norm_logits=batch_norm_logits,
+        )
+
+        self.summarize = SequencePool(d_model, logit_projection_layer)
         # Rebuild the classification process with the correct summary module:
         self.classification_process = nn.Sequential(
             *[
@@ -140,7 +156,8 @@ class ViTEncoder(nn.Module):
         transformer_pre_norm=True,
         transformer_normformer=False,
         transformer_post_norm=False,
-        transformer_position_embedding="relative",  # absolute or relative
+        transformer_absolute_position_embedding=False,
+        transformer_relative_position_embedding=True,
         transformer_embedding_size=256,
         transformer_layers=7,
         transformer_heads=4,
@@ -297,7 +314,8 @@ class ViTEncoder(nn.Module):
                 transformer_embedding_size,
                 transformer_layers,
                 transformer_heads,
-                position_embedding_type=transformer_position_embedding,
+                absolute_position_embedding=transformer_absolute_position_embedding,
+                relative_position_embedding=transformer_relative_position_embedding,
                 source_size=pooling_output_size,
                 mlp_ratio=transformer_mlp_ratio,
                 activation=transformer_activation,
@@ -404,7 +422,8 @@ class ViT(nn.Module):
         transformer_pre_norm=True,
         transformer_normformer=False,
         transformer_post_norm=False,
-        transformer_position_embedding="relative",  # absolute or relative
+        transformer_absolute_position_embedding=False,
+        transformer_relative_position_embedding=True,
         transformer_embedding_size=256,
         transformer_layers=7,
         transformer_heads=4,
@@ -469,7 +488,8 @@ class ViT(nn.Module):
             transformer_pre_norm=transformer_pre_norm,
             transformer_normformer=transformer_normformer,
             transformer_post_norm=transformer_post_norm,
-            transformer_position_embedding=transformer_position_embedding,
+            transformer_absolute_position_embedding=transformer_absolute_position_embedding,
+            transformer_relative_position_embedding=transformer_relative_position_embedding,
             transformer_embedding_size=transformer_embedding_size,
             transformer_layers=transformer_layers,
             transformer_heads=transformer_heads,
@@ -490,9 +510,8 @@ class ViT(nn.Module):
         self.pool = head(
             transformer_embedding_size,
             image_classes,
-            linear_module=linear_module,
             logit_projection_layer=logit_projection_layer,
-            batch_norm=batch_norm_logits,
+            batch_norm_logits=batch_norm_logits,
         )
 
     @property
